@@ -6,7 +6,7 @@ BEGIN {
     use Excel::Template::Base;
     use vars qw ($VERSION @ISA);
 
-    $VERSION  = '0.25';
+    $VERSION  = '0.26';
     @ISA      = qw( Excel::Template::Base );
 }
 
@@ -470,43 +470,45 @@ There is a mailing list at http://groups.google.com/group/ExcelTemplate or excel
 
 =head1 TEST COVERAGE
 
-I used L<Devel::Cover> to test the coverage of my tests. Every release, I intend to improve these numbers.
+I use L<Devel::Cover> to test the coverage of my tests. Every release, I intend to improve these numbers.
 
 Excel::Template is also part of the CPAN Kwalitee initiative, being one of the top 100 non-core modules downloaded from CPAN. If you wish to help out, please feel free to contribute tests, patches, and/or suggestions.
 
   ---------------------------- ------ ------ ------ ------ ------ ------ ------
-  File                           stmt branch   cond    sub    pod   time  total
+  File                           stmt   bran   cond    sub    pod   time  total
   ---------------------------- ------ ------ ------ ------ ------ ------ ------
-  blib/lib/Excel/Template.pm     96.0   64.3   58.8  100.0  100.0   26.3   85.8
-  ...ib/Excel/Template/Base.pm   94.4   50.0    n/a  100.0   75.0    6.6   90.0
-  ...cel/Template/Container.pm  100.0   50.0   33.3  100.0   66.7    4.5   88.1
-  ...emplate/Container/Bold.pm  100.0    n/a    n/a  100.0    0.0    0.2   95.0
-  .../Container/Conditional.pm   95.9   90.0   66.7  100.0    0.0    1.7   91.0
-  ...plate/Container/Format.pm  100.0    n/a    n/a  100.0    0.0    0.6   96.6
-  ...plate/Container/Hidden.pm  100.0    n/a    n/a  100.0    0.0    0.2   95.0
-  ...plate/Container/Italic.pm  100.0    n/a    n/a  100.0    0.0    0.2   95.0
+  blib/lib/Excel/Template.pm     93.8   60.0   58.8  100.0  100.0   24.6   83.3
+  ...ib/Excel/Template/Base.pm   94.4   50.0    n/a  100.0    0.0    7.0   80.0
+  ...cel/Template/Container.pm  100.0   50.0   33.3  100.0    0.0    4.1   83.3
+  ...emplate/Container/Bold.pm  100.0    n/a    n/a  100.0    0.0    0.3   95.0
+  .../Container/Conditional.pm   95.9   90.0   66.7  100.0    0.0    1.2   91.0
+  ...plate/Container/Format.pm  100.0    n/a    n/a  100.0    0.0    0.5   96.6
+  ...plate/Container/Hidden.pm  100.0    n/a    n/a  100.0    0.0    0.0   95.0
+  ...plate/Container/Italic.pm  100.0    n/a    n/a  100.0    0.0    0.1   95.0
   ...ainer/KeepLeadingZeros.pm  100.0  100.0    n/a  100.0    0.0    0.1   96.3
-  ...plate/Container/Locked.pm  100.0    n/a    n/a  100.0    0.0    0.1   95.0
-  ...emplate/Container/Loop.pm   96.8   50.0   50.0  100.0   50.0    0.4   84.6
-  ...late/Container/Outline.pm  100.0    n/a    n/a  100.0    0.0    0.1   95.0
-  ...Template/Container/Row.pm  100.0   75.0    n/a  100.0   50.0    0.3   93.8
-  ...mplate/Container/Scope.pm  100.0    n/a    n/a  100.0    n/a    0.1  100.0
-  ...plate/Container/Shadow.pm  100.0    n/a    n/a  100.0    0.0    0.1   95.0
-  ...te/Container/Strikeout.pm  100.0    n/a    n/a  100.0    0.0    0.1   95.0
-  ...ate/Container/Workbook.pm  100.0    n/a    n/a  100.0    n/a    1.0  100.0
-  ...te/Container/Worksheet.pm   94.7   75.0    n/a  100.0   50.0    1.0   90.3
-  ...Excel/Template/Context.pm   98.0   80.0   75.0  100.0   93.3   23.4   91.8
+  ...plate/Container/Locked.pm  100.0    n/a    n/a  100.0    0.0    0.0   95.0
+  ...emplate/Container/Loop.pm   96.8   50.0   50.0  100.0    0.0    0.3   82.7
+  ...late/Container/Outline.pm  100.0    n/a    n/a  100.0    0.0    0.0   95.0
+  ...Template/Container/Row.pm  100.0   75.0    n/a  100.0    0.0    0.2   90.6
+  ...mplate/Container/Scope.pm  100.0    n/a    n/a  100.0    n/a    0.0  100.0
+  ...plate/Container/Shadow.pm  100.0    n/a    n/a  100.0    0.0    0.0   95.0
+  ...te/Container/Strikeout.pm  100.0    n/a    n/a  100.0    0.0    0.0   95.0
+  ...ate/Container/Workbook.pm  100.0    n/a    n/a  100.0    n/a    2.6  100.0
+  ...te/Container/Worksheet.pm   94.7   75.0    n/a  100.0    0.0    1.0   87.1
+  ...Excel/Template/Context.pm   98.0   80.0   75.0  100.0   73.3   21.4   90.7
   ...Excel/Template/Element.pm  100.0    n/a    n/a  100.0    n/a    0.3  100.0
-  ...mplate/Element/Backref.pm  100.0   50.0   33.3  100.0    0.0    0.2   87.1
-  .../Template/Element/Cell.pm   97.9   75.0   80.0  100.0   66.7    3.9   91.1
+  ...mplate/Element/Backref.pm  100.0   50.0   33.3  100.0    0.0    0.4   87.1
+  .../Template/Element/Cell.pm   97.9   75.0   80.0  100.0    0.0    3.5   88.6
   ...mplate/Element/Formula.pm  100.0    n/a    n/a  100.0    0.0    0.2   94.1
-  ...Template/Element/Range.pm  100.0   66.7    n/a  100.0   66.7    0.2   93.3
-  ...l/Template/Element/Var.pm  100.0    n/a    n/a  100.0    0.0    0.2   94.1
-  ...Excel/Template/Factory.pm  100.0   75.0    n/a  100.0  100.0   15.5   92.4
-  .../Excel/Template/Format.pm   98.4   75.0   33.3  100.0   66.7    8.1   91.2
-  ...xcel/Template/Iterator.pm   98.6   80.0   70.6  100.0   83.3    1.4   90.3
-  ...el/Template/TextObject.pm   92.9   62.5   33.3  100.0   50.0    3.2   83.0
-  Total                          98.0   75.2   63.4  100.0   98.5  100.0   92.2
+  ...te/Element/FreezePanes.pm  100.0    n/a    n/a  100.0    0.0    0.0   95.5
+  ...Template/Element/Image.pm  100.0  100.0    n/a  100.0    0.0    0.1   94.3
+  ...Template/Element/Range.pm  100.0   66.7    n/a  100.0    0.0    0.1   88.9
+  ...l/Template/Element/Var.pm  100.0    n/a    n/a  100.0    0.0    0.0   94.1
+  ...Excel/Template/Factory.pm  100.0   73.1   66.7  100.0  100.0   23.5   91.4
+  .../Excel/Template/Format.pm   98.4   75.0   33.3  100.0   66.7    5.4   90.5
+  ...xcel/Template/Iterator.pm   98.6   80.0   70.6  100.0   50.0    1.1   88.8
+  ...el/Template/TextObject.pm   92.9   62.5   33.3  100.0    0.0    1.8   80.9
+  Total                          97.8   74.3   63.5  100.0   35.7  100.0   89.4
   ---------------------------- ------ ------ ------ ------ ------ ------ ------
 
 =head1 COPYRIGHT
